@@ -2,7 +2,7 @@
 #
 
 listw2sn <- function(listw) {
-	if(class(listw) != "listw") stop("not a listw object")
+	if(!inherits(listw, "listw")) stop("not a listw object")
 	z <- .Call("listw2sn", listw$neighbours, listw$weights,
 		PACKAGE="spdep")
 	res <- as.data.frame(list(from=z[[1]], to=z[[2]], weights=z[[3]]))
